==> v10.5.1.zip: brewman/overlord/src/app/client/client-detail/client-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { Client } from '../client';
import { ClientService } from '../client.service';

@Component({
  selector: 'app-client-detail',
  templateUrl: './client-detail.component.html',
  styleUrls: ['./client-detail.component.css'],
})
export class ClientDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    code: FormControl<number | string>;
    name: FormControl<string | null>;
    enabled: FormControl<boolean>;
    otp: FormControl<number | null>;
  }>;

  item: Client = new Client();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private toaster: ToasterService,
    private ser: ClientService,
  ) {
    this.form = new FormGroup({
      code: new FormControl<number | string>(
        { value: '(Auto)', disabled: true },
        { nonNullable: true },
      ),
      name: new FormControl<string | null>(null),
      enabled: new FormControl<boolean>(false, { nonNullable: true }),
      otp: new FormControl<number | null>(null),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Client };

      this.showItem(data.item);
    });
  }

  showItem(item: Client) {
    this.item = item;
    this.form.setValue({
      code: this.item.code || '(Auto)',
      name: this.item.name,
      enabled: this.item.enabled,
      otp: this.item.otp || null,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.update(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/clients');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/clients');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Client?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Client {
    const formModel = this.form.value;
    this.item.name = formModel.name!;
    this.item.enabled = formModel.enabled!;
    this.item.otp = formModel.otp || undefined;
    return this.item;
  }
}

==> v11.1.2.zip: brewman/overlord/src/app/client/client-detail/client-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { Client } from '../client';
import { ClientService } from '../client.service';

@Component({
  selector: 'app-client-detail',
  templateUrl: './client-detail.component.html',
  styleUrls: ['./client-detail.component.css'],
})
export class ClientDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    code: FormControl<number | string>;
    name: FormControl<string | null>;
    enabled: FormControl<boolean>;
    otp: FormControl<number | null>;
  }>;

  item: Client = new Client();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private toaster: ToasterService,
    private ser: ClientService,
  ) {
    this.form = new FormGroup({
      code: new FormControl<number | string>(
        { value: '(Auto)', disabled: true },
        { nonNullable: true },
      ),
      name: new FormControl<string | null>(null),
      enabled: new FormControl<boolean>(false, { nonNullable: true }),
      otp: new FormControl<number | null>(null),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Client };

      this.showItem(data.item);
    });
  }

  showItem(item: Client) {
    this.item = item;
    this.form.setValue({
      code: this.item.code || '(Auto)',
      name: this.item.name,
      enabled: this.item.enabled,
      otp: this.item.otp || null,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.update(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/clients');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/clients');
      },
      (error) => {
        this.toaster.show('Danger', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Client?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Client {
    const formModel = this.form.value;
    this.item.name = formModel.name ?? '';
    this.item.enabled = formModel.enabled ?? false;
    this.item.otp = formModel.otp || undefined;
    return this.item;
  }
}
